@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__all__ = ["corner", "hist2d", "quantile"]
+__all__ = ["corner", "hist2d", "quantile", "overplot_lines", "overplot_points"]
 
-from .corner import corner, hist2d, quantile
+from .core import hist2d, overplot_lines, overplot_points, quantile
+from .corner import corner
 from .corner_version import __version__  # noqa
 
 __author__ = "Dan Foreman-Mackey"
@@ -10,7 +11,7 @@ __email__ = "foreman.mackey@gmail.com"
 __uri__ = "https://corner.readthedocs.io"
 __license__ = "BSD"
 __description__ = "Make some beautiful corner plots"
-__copyright__ = "Copyright 2013-2020 Daniel Foreman-Mackey"
+__copyright__ = "Copyright 2013-2021 Daniel Foreman-Mackey"
 __contributors__ = "https://github.com/dfm/corner.py/graphs/contributors"
 __bibtex__ = __citation__ = """
 @article{corner,
